==> cms-db_v0.9.tar.gz: admin/locales/de/locale_updateinfo.php <==
<?php
/*  cms-db  Copyright (C) 2007-2010 Jan Hoffmann
    For a full list of authors, see info.php
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

$locale['updateinfo'] = array();

$locale['updateinfo']['title'] = 'Aktualisierungsverwaltung';
$locale['updateinfo']['desc_uptodate'] = 'Diese Installation von cms -db ist auf dem aktuellen Stand.';
$locale['updateinfo']['desc_update-available'] = 'Eine Aktualisierung auf Version %s von cms -db steht bereit.';
$locale['updateinfo']['desc_update-backup'] = 'Sie sollten für den Fehlerfall vor der Installation dieser Aktualisierung eine Sicherungskopie Ihrer Daten anfertigen.';
$locale['updateinfo']['link_moreinfo'] = 'Weiter Informationen';
$locale['updateinfo']['desc_moreinfo'] = 'Zeigt die Website von cms -db an, auf der Sie Informationen zur aktuellen Veröffentlichung nachlesen können.';
$locale['updateinfo']['link_install'] = 'Aktualisierung installieren (automatisch)';
$locale['updateinfo']['desc_install'] = 'Diese Option verlässt die Verwaltungsoberfläche und führt die Aktualisierung für Sie durch. Alle ungespeicherten Änderungen gehen dabei verloren!';
$locale['updateinfo']['link_download'] = 'Aktualisierungspaket herunterladen (für manuelle Aktualisierungen)';
$locale['updateinfo']['desc_download'] = 'Das Aktualisierungspaket wird für manuelle Aktualisierungen benötigt. Laden Sie das Paket herunter und  melden Sie sich ab. Kopieren Sie dann die Dateien auf den Server und beenden Sie die Aktualisierung durch eine erneute Anmeldung als Hauptbenutzer.';
$locale['updateinfo']['desc_checkupdate'] = 'Dieses Werkzeug erlaubt Ihnen auf dem Server von cms -db nach Aktualisierungen zu suchen.';
$locale['updateinfo']['button_checkupdate'] = 'Auf Aktualisierungen prüfen';
$locale['updateinfo']['desc_not-automatic'] = 'Automatische Aktualisierungen sind auf diesem Server nicht möglich, weil die PHP-Erweiterung für cURL nicht installiert ist. Bitte suchen Sie auf der Website von cms -db nach neuen Versionen.';

==> cms-db_v0.9.3.tar.gz: admin/locales/de/locale_updateinfo.php <==
<?php
/*  cms-db  Copyright (C) 2007-2010 Jan Hoffmann
    For a full list of authors, see info.php
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

$locale['updateinfo'] = array();

$locale['updateinfo']['title'] = 'Aktualisierungsverwaltung';
$locale['updateinfo']['desc_uptodate'] = 'Diese Installation von cms -db ist auf dem aktuellen Stand.';
$locale['updateinfo']['desc_update-available'] = 'Eine Aktualisierung auf Version %s von cms -db steht bereit.';
$locale['updateinfo']['desc_update-backup'] = 'Sie sollten für den Fehlerfall vor der Installation dieser Aktualisierung eine Sicherungskopie Ihrer Daten anfertigen.';
$locale['updateinfo']['link_moreinfo'] = 'Weitere Informationen';
$locale['updateinfo']['desc_moreinfo'] = 'Zeigt die Website von cms -db an, auf der Sie Informationen zur aktuellen Veröffentlichung nachlesen können.';
$locale['updateinfo']['link_install'] = 'Aktualisierung installieren (automatisch)';
$locale['updateinfo']['desc_install'] = 'Diese Option verlässt die Verwaltungsoberfläche und führt die Aktualisierung für Sie durch. Alle ungespeicherten Änderungen gehen dabei verloren!';
$locale['updateinfo']['link_download'] = 'Aktualisierungspaket herunterladen (für manuelle Aktualisierungen)';
$locale['updateinfo']['desc_download'] = 'Das Aktualisierungspaket wird für manuelle Aktualisierungen benötigt. Laden Sie das Paket herunter und  melden Sie sich ab. Kopieren Sie dann die Dateien auf den Server und beenden Sie die Aktualisierung durch eine erneute Anmeldung als Hauptbenutzer.';
$locale['updateinfo']['desc_checkupdate'] = 'Dieses Werkzeug erlaubt Ihnen auf dem Server von cms -db nach Aktualisierungen zu suchen.';
$locale['updateinfo']['button_checkupdate'] = 'Auf Aktualisierungen prüfen';
$locale['updateinfo']['desc_not-automatic'] = 'Automatische Aktualisierungen sind auf diesem Server nicht möglich, weil die PHP-Erweiterung für cURL nicht installiert ist. Bitte suchen Sie auf der Website von cms -db nach neuen Versionen.';
